NLSL: parcom.f90 File Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

Modules | Variables
parcom.f90 File Reference

Go to the source code of this file.

## Modules
module | parcom

## Variables
double precision, dimension(nfprm, mxsite), target, save | parcom::fparm
double precision, dimension(mxvar), save | parcom::prmax
double precision, dimension(mxvar), save | parcom::prmin
double precision, dimension(mxvar), save | parcom::prscl
double precision, dimension(mxvar), save | parcom::xfdstp
double precision, dimension(mxjcol), save | parcom::xerr
double precision, dimension(mxspc), save | parcom::serval
double precision, save | parcom::ctol
double precision, save | parcom::ptol
double precision, save | parcom::pftol
double precision, save | parcom::pstep
double precision, save | parcom::pbound
double precision, save | parcom::srange
integer, dimension(niprm, mxsite), target, save | parcom::iparm
integer, dimension(nfprm, mxsite), save | parcom::ixx
integer, dimension(mxvar), save | parcom::ibnd
integer, dimension(mxvar), save | parcom::ixpr
integer, dimension(mxvar), save | parcom::ixst
integer, save | parcom::iser
integer, save | parcom::nser
integer, save | parcom::nsite
integer, save | parcom::nprm
integer, save | parcom::njcol
integer, save | parcom::nshift
integer, save | parcom::noneg
integer, save | parcom::itridg
integer, save | parcom::iitrfl
integer, save | parcom::jacobi
integer, save | parcom::ixp1p
integer, save | parcom::ixs1p
integer, save | parcom::mxpitr
integer, save | parcom::output
logical, save | parcom::mtxclc
character *9, dimension(mxjcol), save | parcom::tag